==> mastapy-14.0.0rc2.tar.gz: mastapy-14.0.0rc2/mastapy/_private/utility/units_and_measurements/measurements/_1665.py <==
"""AngleSmall"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1655
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal import utility

_ANGLE_SMALL = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "AngleSmall"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="AngleSmall")
    CastSelf = TypeVar("CastSelf", bound="AngleSmall._Cast_AngleSmall")


__docformat__ = "restructuredtext en"
__all__ = ("AngleSmall",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AngleSmall:
    """Special nested class for casting AngleSmall to subclasses."""

    __parent__: "AngleSmall"

    @property
    def measurement_base(self: "CastSelf") -> "_1655.MeasurementBase":
        return self.__parent__._cast(_1655.MeasurementBase)

    @property
    def angle_small(self: "CastSelf") -> "AngleSmall":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class AngleSmall(_1655.MeasurementBase):
    """AngleSmall

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ANGLE_SMALL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_AngleSmall":
        """Cast to another type.

        Returns:
            _Cast_AngleSmall
        """
        return _Cast_AngleSmall(self)

==> mastapy-14.0.3.post1.tar.gz: mastapy-14.0.3.post1/mastapy/_private/utility/units_and_measurements/measurements/_1665.py <==
"""Angle"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1657

_ANGLE = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Angle"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Angle")
    CastSelf = TypeVar("CastSelf", bound="Angle._Cast_Angle")


__docformat__ = "restructuredtext en"
__all__ = ("Angle",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Angle:
    """Special nested class for casting Angle to subclasses."""

    __parent__: "Angle"

    @property
    def measurement_base(self: "CastSelf") -> "_1657.MeasurementBase":
        return self.__parent__._cast(_1657.MeasurementBase)

    @property
    def angle(self: "CastSelf") -> "Angle":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Angle(_1657.MeasurementBase):
    """Angle

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ANGLE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Angle":
        """Cast to another type.

        Returns:
            _Cast_Angle
        """
        return _Cast_Angle(self)
